@@ -1,6 +1,8 @@
 #ifndef BBOX_DECO_H
 #define BBOX_DECO_H
 
+#include <string>
+#include <vector>
 #include "SceneNode.h"
 
 //
@@ -12,7 +14,6 @@
 #include "geom.h"
 
 #include "RenderContext.h"
-#include "String.h"
 #include "Material.h"
 
 namespace rgl {
@@ -32,7 +33,7 @@ struct AxisInfo {
   AxisInfo(AxisInfo& from);
   ~AxisInfo();
   void draw(RenderContext* renderContext, Vertex4& v, Vertex4& dir, Matrix4x4& modelview, 
-            Vertex& marklen, String& string);
+            Vertex& marklen, std::string& string);
             
   int getNticks(float low, float high);
   double getTick(float low, float high, int index); /* double since it might be NA_REAL */
@@ -40,9 +41,9 @@ struct AxisInfo {
   int    mode;
   int    nticks;
   float* ticks;
-  StringArray textArray;
   int    len;
   float  unit;
+  std::vector<std::string> textArray;
 };
 
 typedef void (*userAxisPtr)(void *userData, int axis, int edge[3]);
@@ -57,9 +58,9 @@ public:
   Vertex getMarkLength(const AABox& boundingBox) const;
   int getAttributeCount(SceneNode* subscene, AttribID attrib);
   void getAttribute(SceneNode* subscene, AttribID attrib, int first, int count, double* result);
-  String  getTextAttribute(SceneNode* subscene, AttribID attrib, int index);
+  std::string  getTextAttribute(SceneNode* subscene, AttribID attrib, int index);
   Material* getMaterial()  { return &material; }
-  virtual void getTypeName(char* buffer, int buflen) { strncpy(buffer, "bboxdeco", buflen); };
+  virtual std::string getTypeName() { return "bboxdeco"; };
   Vec3 marginVecToDataVec(Vec3 marginvec, RenderContext* renderContext, Material* material);
   Vec3 marginNormalToDataNormal(Vec3 marginvec, RenderContext* renderContext, Material* material);
   void setAxisCallback(userAxisPtr fn, void * user, int axis);
