@@ -1,6 +1,6 @@
 /*
  * GL2PS, an OpenGL to PostScript Printing Library
- * Copyright (C) 1999-2017 C. Geuzaine
+ * Copyright (C) 1999-2020 C. Geuzaine
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of either:
@@ -33,8 +33,8 @@
  * Please report all bugs and problems to <gl2ps@geuz.org>.
  */
 
-#ifndef __GL2PS_H__
-#define __GL2PS_H__
+#ifndef GL2PS_H
+#define GL2PS_H
 
 #ifndef RGL_NO_OPENGL
 
@@ -51,11 +51,9 @@
 #  endif
 #  if !defined(NOMINMAX)
 #    define NOMINMAX
-#    include <windows.h>
-#    undef NOMINMAX
-#  else
-#    include <windows.h>
 #  endif
+#  include <windows.h>
+#  undef NOMINMAX
 #  if defined(GL2PSDLL)
 #    if defined(GL2PSDLL_EXPORTS)
 #      define GL2PSDLL_API __declspec(dllexport)
@@ -94,14 +92,14 @@
 
 #define GL2PS_MAJOR_VERSION 1
 #define GL2PS_MINOR_VERSION 4
-#define GL2PS_PATCH_VERSION 0
+#define GL2PS_PATCH_VERSION 2
 #define GL2PS_EXTRA_VERSION ""
 
 #define GL2PS_VERSION (GL2PS_MAJOR_VERSION + \
                        0.01 * GL2PS_MINOR_VERSION + \
                        0.0001 * GL2PS_PATCH_VERSION)
 
-#define GL2PS_COPYRIGHT "(C) 1999-2017 C. Geuzaine"
+#define GL2PS_COPYRIGHT "(C) 1999-2020 C. Geuzaine"
 
 /* Output file formats (the values and the ordering are important!) */
 
@@ -145,6 +143,7 @@
 #define GL2PS_NO_BLENDING          (1<<11)
 #define GL2PS_TIGHT_BOUNDING_BOX   (1<<12)
 #define GL2PS_NO_OPENGL_CONTEXT    (1<<13)
+#define GL2PS_NO_TEX_FONTSIZE      (1<<14)
 
 /* Arguments for gl2psEnable/gl2psDisable */
 
@@ -153,7 +152,6 @@
 #define GL2PS_LINE_STIPPLE        3
 #define GL2PS_BLEND               4
 
-
 /* Arguments for gl2psLineCap/Join */
 
 #define GL2PS_LINE_CAP_BUTT       0
@@ -223,6 +221,9 @@ GL2PSDLL_API GLint gl2psTextOpt(const char *str, const char *fontname,
 GL2PSDLL_API GLint gl2psTextOptColor(const char *str, const char *fontname,
                                      GLshort fontsize, GLint align, GLfloat angle,
                                      GL2PSrgba color);
+GL2PSDLL_API GLint gl2psTextOptColorBL(const char *str, const char *fontname,
+                                       GLshort fontsize, GLint align, GLfloat angle,
+                                       GL2PSrgba color, GLfloat blx, GLfloat bly);
 GL2PSDLL_API GLint gl2psSpecial(GLint format, const char *str);
 GL2PSDLL_API GLint gl2psSpecialColor(GLint format, const char *str, GL2PSrgba rgba);
 GL2PSDLL_API GLint gl2psDrawPixels(GLsizei width, GLsizei height,
@@ -235,6 +236,7 @@ GL2PSDLL_API GLint gl2psLineCap(GLint value);
 GL2PSDLL_API GLint gl2psLineJoin(GLint value);
 GL2PSDLL_API GLint gl2psLineWidth(GLfloat value);
 GL2PSDLL_API GLint gl2psBlendFunc(GLenum sfactor, GLenum dfactor);
+GL2PSDLL_API GLint gl2psSorting(GLint mode);
 
 /* referenced in the documentation, but not fully documented */
 GL2PSDLL_API GLint gl2psForceRasterPos(GL2PSvertex *vert);
@@ -252,11 +254,12 @@ GL2PSDLL_API GLint gl2psDrawImageMap(GLsizei width, GLsizei height,
 GL2PSDLL_API const char *gl2psGetFileExtension(GLint format);
 GL2PSDLL_API const char *gl2psGetFormatDescription(GLint format);
 GL2PSDLL_API GLint gl2psGetFileFormat(void);
+GL2PSDLL_API GLint gl2psSetTexScaling(GLfloat scaling);
 
 #if defined(__cplusplus)
 }
 #endif
 
-#endif 
+#endif /* RGL_NO_OPENGL */
 
-#endif /* __GL2PS_H__ */
+#endif /* GL2PS_H */
